@@ -1,9 +1,10 @@
-
 package Data::Localize::Localizer;
 use utf8;
 use Moo;
 use Carp ();
 use Data::Localize;
+use Encode ();
+
 BEGIN {
     if (Data::Localize::DEBUG) {
         require Data::Localize::Log;
@@ -16,6 +17,12 @@ has _localizer => (
     weak_ref => 1,
 );
 
+has initialized => (
+    is => 'rw',
+    default => 0,
+    init_arg => undef,
+);
+
 has formatter => (
     is => 'rw',
     lazy => 1,
@@ -30,6 +37,10 @@ sub _build_formatter {
     return Data::Localize::Format::Maketext->new();
 }
 
+sub BUILD {
+    $_[0]->initialized(1);
+}
+
 sub register {
     my ($self, $loc) = @_;
     if ($self->_localizer) {
